Toolchain-simplez are a set of tools for working with the educational processor
Simplez. The included tools are:

* sasm: Simplez Assembler
* ssim: Simplez simulator
* sreset: Simplez Reset
* sboot: Simplez loader (a bootloader is needed)
